@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.9"__email__ = "vkhomenko@qubell.com"
+__email__ = "vkhomenko@qubell.com"
 
 import logging as log
 import requests
